@@ -1,6 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import Model, fields
+from trytond.pyson import Not, Bool, Eval
 import luhn
 
 
@@ -8,7 +9,7 @@ class Party(Model):
     _name = 'party.party'
 
     siren = fields.Char('SIREN', select=1, states={
-        'readonly': "active == False",
+        'readonly': Not(Bool(Eval('active'))),
         }, size=9)
 
     def __init__(self):
@@ -25,6 +26,8 @@ class Party(Model):
         Check validity of SIREN
         '''
         for party in self.browse(cursor, user, ids):
+            if party.siren and not luhn.validate(party.siren):
+                return False
             if party.siren:
                 if len(party.siren) != 9 or not luhn.validate(party.siren):
                     return False
